import { routerRedux } from 'dva/router';
import { login, userInfo } from '../services/login';
import { fullPath } from '../utils/helper';
import { setToken, setUser } from '../utils/auth';
import { errors } from '../utils/error';

export default {
  namespace: 'login',
  state: {},
  reducers: {},
  effects: {
    *login({ payload }, { call, put }) {
      const loginRequest = {
        type: 'userName',
        data: payload.userName,
        authRequest: {
          type: 'password',
          parameters: {
            cipher: payload.password,
          },
        },
      };
      const result = yield call(login, loginRequest);
      const { tokenId, authResponse, remainedAuthRequirements } = result;
      if (authResponse.status !== 'authed' && authResponse.status !== 'skipped') {
        throw errors.wrongPassword();
      }
      const { requirements } = remainedAuthRequirements;
      if (requirements.length > 0) {
        throw errors.unsupportedAuthType(requirements);
      }
      yield call(setToken, tokenId);
      const uInfo = yield call(userInfo);
      yield call(setUser, uInfo.id, uInfo.name);
      yield put(routerRedux.push(fullPath('/domain')));
    },
  },
  subscriptions: {},
};
